@@ -18,26 +18,23 @@ class NotificationManager:
         self._logger = logger
         self._to_publish = []
 
-    def stage(self, event_type: str, message, group_id: str, event_cause: str = None):
-        self._to_publish.append((event_type, message, group_id, event_cause))
+    def stage(self, event_type: str, message, group_id: str, **kwargs):
+        self._to_publish.append((event_type, message, group_id, kwargs))
 
     def flush(self):
         with concurrent.futures.ThreadPoolExecutor(max_workers=16) as executor:
             for to_publish in self._to_publish:
-                executor.submit(self.publish, *to_publish)
+                executor.submit(self.publish, *to_publish[:-1], **to_publish[-1])
 
-    def publish(self, event_type: str, message, group_id: str, event_cause: str = None):
+    def publish(self, event_type: str, message, group_id: str, **kwargs):
         if type(message) is not str:
             message = message.json()
         try:
-            message_attributes = {"eventType": event_type}
-            if event_cause:
-                message_attributes["eventCause"] = event_cause
             self._publish(
                 message=message,
                 message_deduplication_id=uuid4().hex,
                 group_id=group_id,
-                message_attributes=message_attributes,
+                message_attributes={"eventType": event_type, **kwargs},
             )
         except InternalError as e:
             if self._logger:
@@ -64,11 +61,11 @@ class NotificationManagerMock:
     def __init__(self, resource_name: str, logger=None):
         pass
 
-    def stage(self, event_type: str, message, group_id: str, event_cause: str = None):
+    def stage(self, event_type: str, message, group_id: str, **kwargs):
         pass
 
     def flush(self):
         pass
 
-    def publish(self, event_type: str, message, group_id: str, event_cause: str = None):
+    def publish(self, event_type: str, message, group_id: str, **kwargs):
         pass
